@@ -150,6 +150,14 @@ impl FileTypeDescription for FileType {
                 FileType::Flac => Some(4),
                 FileType::Matroska => Some(4),
                 FileType::Wasm => Some(4),
+                FileType::Class => Some(4),
+                FileType::Elf => Some(4),
+                FileType::Wav => Some(12),
+                FileType::Avi => Some(12),
+                FileType::Aiff => Some(12),
+                FileType::Tiff => Some(4),
+                FileType::Sqlite3 => Some(16),
+                FileType::Ico => Some(4),
             }
         } else {
             match self {
