@@ -45,6 +45,14 @@
 //! - Flac
 //! - Matroska (mkv, mka, mks, mk3d, webm)
 //! - Wasm
+//! - Java Class/Mach-O Fat Binary
+//! - Elf (Executable and Linkable Format)
+//! - Wav
+//! - Avi
+//! - Aiff
+//! - Tiff
+//! - Sqlite3 (`.db`)
+//! - Ico
 //!
 //! ## First Step
 //!
@@ -528,6 +536,41 @@ mod tests {
         test_detect_match("files/test-wasm.wasm", FileType::Wasm);
     }
 
+    #[test]
+    fn test_class_detect() {
+        test_detect_match("files/test-class.class", FileType::Class);
+    }
+
+    #[test]
+    fn so_class_detect() {
+        test_detect_match("files/test-so.so", FileType::Elf);
+    }
+
+    #[test]
+    fn wav_class_detect() {
+        test_detect_match("files/test-wav.wav", FileType::Wav);
+    }
+
+    #[test]
+    fn avi_class_detect() {
+        test_detect_match("files/test-avi.avi", FileType::Avi);
+    }
+
+    #[test]
+    fn aif_class_detect() {
+        test_detect_match("files/test-aif.aif", FileType::Aiff);
+    }
+
+    #[test]
+    fn tiff_class_detect() {
+        test_detect_match("files/rust-logo.tiff", FileType::Tiff);
+    }
+
+    #[test]
+    fn sqlite3_class_detect() {
+        test_detect_match("files/test-db.db", FileType::Sqlite3);
+    }
+
     // False positive - how to avoid?
     #[test]
     fn test_flac_txt_detect() {
@@ -539,6 +582,11 @@ mod tests {
         test_detect_match("files/test-mka.mka", FileType::Matroska);
     }
 
+    #[test]
+    fn test_ico_detect() {
+        test_detect_match("files/rust-logo.ico", FileType::Ico);
+    }
+
     #[test]
     fn test_txt_no_match() {
         test_detect_no_match("files/text");
