@@ -131,6 +131,14 @@ impl FileTypeMatcher for FileType {
             FileType::Flac => flac_test(&relative_position, step, &bytes),
             FileType::Matroska => matroska_test(&relative_position, step, &bytes),
             FileType::Wasm => wasm_test(&relative_position, step, &bytes),
+            FileType::Class => class_test(&relative_position, step, &bytes),
+            FileType::Elf => elf_test(&relative_position, step, &bytes),
+            FileType::Wav => wav_test(&relative_position, step, &bytes),
+            FileType::Avi => avi_test(&relative_position, step, &bytes),
+            FileType::Aiff => aiff_test(&relative_position, step, &bytes),
+            FileType::Tiff => tiff_test(&relative_position, step, &bytes),
+            FileType::Sqlite3 => sqlite3_test(&relative_position, step, &bytes),
+            FileType::Ico => ico_test(&relative_position, step, &bytes),
         }
     }
 }
@@ -205,7 +213,7 @@ fn windowing_test(bytes: &[u8], matching: &[u8]) -> TestResult {
                     }
                 }
                 if !any {
-                    i += (matching.len() - 1);
+                    i += matching.len() - 1;
                 }
             }
 
@@ -344,6 +352,94 @@ fn wasm_test(relative_position: &RelativePosition, step: &Step, bytes: &[u8]) ->
     return TestResult::NotMatched;
 }
 
+const CLASS_SIGNATURE: [u8; 4] = [0xCA, 0xFE, 0xBA, 0xBE];
+fn class_test(relative_position: &RelativePosition, step: &Step, bytes: &[u8]) -> TestResult {
+    if *relative_position == RelativePosition::Start && *step == Step::Small {
+        return slice_test(&bytes, &CLASS_SIGNATURE);
+    }
+
+    return TestResult::NotMatched;
+}
+
+const ELF_SIGNATURE: [u8; 4] = [0x7F, 0x45, 0x4C, 0x46];
+fn elf_test(relative_position: &RelativePosition, step: &Step, bytes: &[u8]) -> TestResult {
+    if *relative_position == RelativePosition::Start && *step == Step::Small {
+        return slice_test(&bytes, &ELF_SIGNATURE);
+    }
+
+    return TestResult::NotMatched;
+}
+
+const WAV_SIGNATURE_1: [u8; 4] = [0x52, 0x49, 0x46, 0x46];
+const WAV_SIGNATURE_2: [u8; 4] = [0x57, 0x41, 0x56, 0x45];
+fn wav_test(relative_position: &RelativePosition, step: &Step, bytes: &[u8]) -> TestResult {
+    if *relative_position == RelativePosition::Start && *step == Step::Small {
+        if bytes.len() >= 12 {
+            return slice_test(&bytes, &WAV_SIGNATURE_1)
+                .and(|| slice_test(&bytes[8..], &WAV_SIGNATURE_2));
+        }
+    }
+
+    return TestResult::NotMatched;
+}
+
+const AVI_SIGNATURE_1: [u8; 4] = [0x52, 0x49, 0x46, 0x46];
+const AVI_SIGNATURE_2: [u8; 4] = [0x41, 0x56, 0x49, 0x20];
+fn avi_test(relative_position: &RelativePosition, step: &Step, bytes: &[u8]) -> TestResult {
+    if *relative_position == RelativePosition::Start && *step == Step::Small {
+        if bytes.len() >= 12 {
+            return slice_test(&bytes, &AVI_SIGNATURE_1)
+                .and(|| slice_test(&bytes[8..], &AVI_SIGNATURE_2));
+        }
+    }
+
+    return TestResult::NotMatched;
+}
+
+const AIFF_SIGNATURE_1: [u8; 4] = [0x46, 0x4F, 0x52, 0x4D];
+const AIFF_SIGNATURE_2: [u8; 4] = [0x41, 0x49, 0x46, 0x46];
+fn aiff_test(relative_position: &RelativePosition, step: &Step, bytes: &[u8]) -> TestResult {
+    if *relative_position == RelativePosition::Start && *step == Step::Small {
+        if bytes.len() >= 12 {
+            return slice_test(&bytes, &AIFF_SIGNATURE_1)
+                .and(|| slice_test(&bytes[8..], &AIFF_SIGNATURE_2));
+        }
+    }
+
+    return TestResult::NotMatched;
+}
+
+const TIFF_SIGNATURE_1: [u8; 4] = [0x49, 0x49, 0x2A, 0x00];
+const TIFF_SIGNATURE_2: [u8; 4] = [0x4D, 0x4D, 0x00, 0x2A];
+fn tiff_test(relative_position: &RelativePosition, step: &Step, bytes: &[u8]) -> TestResult {
+    if *relative_position == RelativePosition::Start && *step == Step::Small {
+        return slice_test(&bytes, &TIFF_SIGNATURE_1)
+            .or_else(|| slice_test(&bytes, &TIFF_SIGNATURE_2));
+    }
+
+    return TestResult::NotMatched;
+}
+
+const SQLITE3_SIGNATURE_1: [u8; 16] = [
+    0x53, 0x51, 0x4C, 0x69, 0x74, 0x65, 0x20, 0x66, 0x6F, 0x72, 0x6D, 0x61, 0x74, 0x20, 0x33, 0x00,
+];
+fn sqlite3_test(relative_position: &RelativePosition, step: &Step, bytes: &[u8]) -> TestResult {
+    if *relative_position == RelativePosition::Start && *step == Step::Small {
+        return slice_test(&bytes, &SQLITE3_SIGNATURE_1);
+    }
+
+    return TestResult::NotMatched;
+}
+
+const ICO_SIGNATURE_1: [u8; 4] = [0x00, 0x00, 0x01, 0x00];
+fn ico_test(relative_position: &RelativePosition, step: &Step, bytes: &[u8]) -> TestResult {
+    if *relative_position == RelativePosition::Start && *step == Step::Small {
+        return slice_test(&bytes, &ICO_SIGNATURE_1);
+    }
+
+    return TestResult::NotMatched;
+}
+
 fn slice_test(bytes: &[u8], matching: &[u8]) -> TestResult {
     if bytes.len() >= matching.len() {
         if &bytes[..matching.len()] == matching {
