@@ -27,6 +27,12 @@
 /// FileType
 #[derive(Debug, Copy, Clone, Eq, PartialEq)]
 pub enum FileType {
+    /// Zip File format, this includes:
+    /// - jar
+    /// - docx/xlsx/pptx
+    /// - Apk
+    /// - Aar
+    /// - odt/ods/odp
     Zip,
     Rar,
     Rar5,
@@ -51,11 +57,32 @@ pub enum FileType {
     Matroska,
     /// WebAssembly
     Wasm,
+    /// Java class and Mach-O Fat Binary
+    Class,
+    /// Executable and Linkable Format
+    Elf,
+    /// Waveform Audio File Format
+    Wav,
+    Avi,
+    /// Audio Interchange File Format
+    /// - aiff
+    /// - aif
+    /// - aifc
+    /// - snd
+    /// - iff
+    Aiff,
+    /// Tagged Image File Format
+    /// - Tiff
+    /// - Tif
+    Tiff,
+    /// SQLite 3 Database
+    Sqlite3,
+    Ico,
 }
 
 impl FileType {
     /// Gets all variants of [FileType]
-    pub fn variants() -> [FileType; 14] {
+    pub fn variants() -> [FileType; 22] {
         [
             FileType::Zip,
             FileType::Rar,
@@ -71,6 +98,14 @@ impl FileType {
             FileType::Flac,
             FileType::Matroska,
             FileType::Wasm,
+            FileType::Class,
+            FileType::Elf,
+            FileType::Wav,
+            FileType::Avi,
+            FileType::Aiff,
+            FileType::Tiff,
+            FileType::Sqlite3,
+            FileType::Ico,
         ]
     }
 
@@ -90,6 +125,14 @@ impl FileType {
             FileType::Flac => FileRootType::Flac,
             FileType::Matroska => FileRootType::Matroska,
             FileType::Wasm => FileRootType::Wasm,
+            FileType::Class => FileRootType::Class,
+            FileType::Elf => FileRootType::Elf,
+            FileType::Wav => FileRootType::Wav,
+            FileType::Avi => FileRootType::Avi,
+            FileType::Aiff => FileRootType::Aiff,
+            FileType::Tiff => FileRootType::Tiff,
+            FileType::Sqlite3 => FileRootType::Sqlite3,
+            FileType::Ico => FileRootType::Ico,
         }
     }
 }
@@ -109,4 +152,12 @@ pub enum FileRootType {
     Flac,
     Matroska,
     Wasm,
+    Class,
+    Elf,
+    Wav,
+    Avi,
+    Aiff,
+    Tiff,
+    Sqlite3,
+    Ico,
 }
